@@ -61,7 +61,9 @@ class Configure:
             self.create_vm(row.prefix, vm_count=row.machine_count)
             print('\n####')
 
-    def set_up(self):
+    def set_up(self, pipeline_name=None):
         # TODO: wipe-out existent conflicting infrastructure
         infrastructure = pd.read_json(self.path.VM_SETTINGS).T
+        if pipeline_name is not None:
+            infrastructure = infrastructure.query(f"pipeline_name=='{pipeline_name}'")
         self.fmt_vm_cnf(infrastructure.fillna(''))
